@@ -1,8 +1,8 @@
 #' Get coverge from tsn
 #'
 #' @export
-#' @template common
 #' @template tsn
+#' @inheritParams accepted_names
 #' @examples \dontrun{
 #' # coverage data
 #' coverage(tsn=28727)
@@ -15,5 +15,5 @@ coverage <- function(tsn, wt = "json", raw = FALSE, ...) {
   if (raw || wt == "xml") return(out)
   res <- parse_raw(out)
   if (is.null(res$taxonCoverage)) res$taxonCoverage <- ""
-  dr_op(tibble::as_data_frame(res), "class")
+  dr_op(tibble::as_tibble(res), "class")
 }
