@@ -1,7 +1,7 @@
 #' Search by scientific name
 #'
 #' @export
-#' @template common
+#' @inheritParams accepted_names
 #' @inheritParams any_match_count
 #' @return a data.frame
 #' @seealso \code{\link{search_common}}
@@ -12,7 +12,7 @@
 search_scientific <- function(x, wt = "json", raw = FALSE, ...) {
   out <- itis_GET("searchByScientificName", list(srchKey = x), wt, ...)
   if (raw || wt == "xml") return(out)
-  tibble::as_data_frame(
+  tibble::as_tibble(
     dr_op(parse_raw(out)$scientificNames, "class")
   )
 }
