@@ -1,9 +1,9 @@
 context("kingdom functions")
 
 test_that("kingdom_name basic functionality works", {
-  skip_on_cran()
-
-  aa <- kingdom_name(202385)
+  vcr::use_cassette("kingdom_name", {
+    aa <- kingdom_name(202385)
+  })
 
   expect_is(aa, "data.frame")
   expect_is(aa, "tbl_df")
@@ -15,9 +15,9 @@ test_that("kingdom_name basic functionality works", {
 })
 
 test_that("kingdom_names basic functionality works", {
-  skip_on_cran()
-
-  aa <- kingdom_names()
+  vcr::use_cassette("kingdom_names", {
+    aa <- kingdom_names()
+  })
 
   expect_is(aa, "data.frame")
   expect_is(aa, "tbl_df")
@@ -28,14 +28,13 @@ test_that("kingdom_names basic functionality works", {
 })
 
 test_that("kingdom functions fail well", {
-  skip_on_cran()
-
   expect_error(kingdom_name(), "\"tsn\" is missing")
 
   expect_error(kingdom_names(wt = "ffa"), "'wt' must be one of")
 
-  # tsn's not found lead to 0 row data.frame's
-  tmp <- kingdom_name(tsn = "Asdfasdfa")
-  expect_is(tmp, "tbl_df")
-  expect_equal(NROW(tmp), 0)
+  vcr::use_cassette("kingdom_name-fails-well", {
+    # tsn's not found lead to 404
+    expect_error(kingdom_name(tsn = "Asdfasdfa"),
+      "Bad Request \\(HTTP 400\\)", class = "error")
+  })
 })
